@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11526 2019-05-07 08:36:46Z Andy $
+# $Id: Patch.py 11632 2019-06-11 20:30:52Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $ (last)
-# $Date: 2019-05-07 17:36:46 +0900 (週二, 07 五月 2019) $
-# $Revision: 11526 $
+# $Author: Lavender $ (last)
+# $Date: 2019-06-12 04:30:52 +0800 (週三, 12 六月 2019) $
+# $Revision: 11632 $
 #
 # Contributors:
 #  Bear
@@ -215,7 +215,24 @@ def attachURLs(settings, urlpatterns):
     urlpatterns += patterns('',
         url(r'^django-des/', include(des_urls)),
     )
-
+    
+    addMetricsUrl = False
+    if hasattr(settings ,'IUNO_CLOUD_ENABLE'):
+        if settings.IUNO_CLOUD_ENABLE:
+            if hasattr(settings ,'IUNO_CLOUD_SERVICES'):
+                services = settings.IUNO_CLOUD_SERVICES
+                if 'metrics' in services:
+                    addMetricsUrl = True
+            else:
+                addMetricsUrl = True
+                
+    if addMetricsUrl:
+        from Iuno.cloud.metrics.views import sendStatsd, getStatsdImage
+        urlpatterns += patterns('',
+            url(r'^metrics/send/', sendStatsd, name='sendStatsd'),
+            url(r'^metrics/image/', getStatsdImage, name='getStatsdImage'),
+        )
+    
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
         if DJANGO_VERSION >= 11100: # django >= 1.11
             from django.views.static import serve
