@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11709 2019-09-18 08:40:38Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Andy $ (last)
+# $Date: 2019-09-18 16:40:38 +0800 (週三, 18 九月 2019) $
+# $Revision: 11709 $
 
 import os
 import sys
@@ -22,7 +22,7 @@ import warnings
 from Iuno import warnWithout, update, require
 from Iuppiter.DjangoUtil import (extendInstalledApps, extendMiddlewareClasses, 
                                  extendTemplateContextProcessors, 
-                                 extendAuthenticationBackend)
+                                 extendAuthenticationBackend, DJANGO_VERSION)
 
 
 def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
@@ -103,9 +103,14 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     
     #=========================================================================
     #  Django templates.
+    if DJANGO_VERSION >= 11000:
+        contextProcessorsText = "django.template.context_processors.request"
+    else:
+        contextProcessorsText = "django.core.context_processors.request"
+        
     ADDING_TEMPLATES_CONTEXT_PROCESSORS = (
         "account.context_processors.account",
-        "django.core.context_processors.request", 
+        contextProcessorsText, 
         "pinax_theme_bootstrap.context_processors.theme",
         "social_django.context_processors.backends",
         "social_django.context_processors.login_redirect",                             
